PySight Output Object
=====================

If the *In Memory* option was checked in the GUI or
enabled in the configuration file, PySight will
return a :class:`PySightOuput`
instance containing the processed data and useful methods to
work with it.

.. automodule:: pysight.nd_hist_generator.outputs
    :members:
    :undoc-members: OutputParser
    :show-inheritance:
